package ru.myitschool.work.ui.login;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.lifecycle.LiveData;
import androidx.lifecycle.MutableLiveData;

import ru.myitschool.work.api.data.SignRepositoryImpl;
import ru.myitschool.work.api.domain.entity.employee.EmpolyeeEntity;
import ru.myitschool.work.api.domain.useCases.sign.LoginEmployeeUseCase;

public class LoginViewModel {
    private final MutableLiveData<String> mutableErrorLiveData = new MutableLiveData<>();
    public final LiveData<String> errorLiveData = mutableErrorLiveData;

    private final MutableLiveData<EmpolyeeEntity> mutableOpenLiveData = new MutableLiveData<>();
    public final LiveData<EmpolyeeEntity> openLiveData = mutableOpenLiveData;

    private final LoginEmployeeUseCase loginEmployeeUseCase = new LoginEmployeeUseCase(
            SignRepositoryImpl.getInstance()
    );

    @Nullable
    private String email;
    @Nullable
    private String password;

    public void changeEmail(@NonNull String email) {
        this.email = email;
    }

    public void changePassword(@NonNull String password) {
        this.password = password;
    }

    public void confirm() {
        final String currentEmail = email;
        final String currentPassword = password;

        if (currentEmail == null || currentEmail.isEmpty()) {
            mutableErrorLiveData.postValue("Пароль пустой!");
            return;
        }
        if (currentPassword == null || currentPassword.isEmpty()) {
            mutableErrorLiveData.postValue("email пустой!");
            return;
        }
        loginEmployeeUseCase.execute(currentEmail, currentPassword, status -> {
            if (status.getStatusCode() == 200 && status.getErrors() == null && status.getValue() != null) {
                mutableOpenLiveData.postValue(status.getValue());
            } else if (status.getStatusCode() == 401) mutableErrorLiveData.postValue("Данные не верны. Попробуйте ещё разок :(");
            else mutableErrorLiveData.postValue("Вы не подключены к интернету :(");
        });
    }

}
